@@ -9,13 +9,14 @@ def default_checkers():
             'heartbeat.checkers.distribution_list',
             'heartbeat.checkers.debug_mode',
             'heartbeat.checkers.python',
+            'heartbeat.checkers.host'
         ]
     prepare_redis(heartbeat)
     return heartbeat
 
 
 def prepare_redis(heartbeat):
-    if 'heartbeat.checkers.redis' in heartbeat['checkers']:
+    if 'heartbeat.checkers.redis_status' in heartbeat['checkers']:
         redis = getattr(settings, 'CACHEOPS_REDIS', None)
         if redis is None:
             raise ImproperlyConfigured(
