@@ -1,4 +1,7 @@
-from django.conf.urls import url
+try:
+    from django.conf.urls import url
+except:
+    from django.urls import re_path as url
 
 from . import views
 
